USBAlternateInterface class

Constructors

USBAlternateInterface({required int alternateSetting, required List<USBEndpoint>? endpoints})

Properties

alternateSetting → int
final
endpoints → List<USBEndpoint>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromAlternateInterfaces(List alternateInterfaces) → List<USBAlternateInterface>